## Usage

This is intended to be used in a project that uses the diagrams (diagrams as code) python package as an extention of the icons.

To import the latest build of this library into your project use `pip install ExtendedDiagramIcons`